
graphe
========

**graphe** is a Python library for creating, traversing and visualising
graphs. Most algorithms are inspired by the Algorithms Course [#f1]_ by Robert
Sedgewick. The Python classes are reimplementations of Java code.


.. figure:: images/graph.png
  :width: 400
  :align: center

  Graphviz visualisation of an undirected graph loaded from 'mediumG.txt', courtesy
  R. Sedgewick, Princeton.


.. note::

   This is a project under unpredictable development. Class names and code
   organisation is subject to (breaking) changes.



.. rubric:: Footnotes

.. [#f1] Algorithms - https://algs4.cs.princeton.edu


.. toctree::
   :caption: Practical
   :maxdepth: 2
   :hidden:

   install

.. toctree::
   :caption: Documentation
   :maxdepth: 2
   :hidden:

   graph
   graphappl
   digraph
   digraphappl
   utils
   files

.. toctree::
  :caption: Examples
  :maxdepth: 2
  :hidden:

  usage
